# Bundestag2017Forecast
# table of forecasting errors
library(xtable)
library(dplyr)

setwd('your/directory/here')

err <- read.csv('errors_bundesgebiet.csv', stringsAsFactors = F) %>% tbl_df

t_err_1 <-
err %>% filter(elec_year >= 1998, elec_year < 2017) %>% group_by(party) %>%
  summarise(error_abs = mean(error_abs), error2 = sqrt(mean(error2)),
            error_abs_w = mean(error_abs_w), error2_w = sqrt(mean(error2_w)),
            error_abs_naive1 = mean(error_abs_naive1),
            error2_naive1 = sqrt(mean(error2_naive1)),
            error_abs_naive2 = mean(error_abs_naive2),
            error2_naive2 = sqrt(mean(error2_naive2)),
            party_id = unique(party_id)) %>%
  arrange(party_id) %>% select(-party_id)
t_err_1$party <- c('CDU/CSU', 'SPD', 'Die Linke/PDS', 'Bündnis 90/Die Grünen',
                   'FDP', 'Others')


t_err_2 <-
  err %>% filter(elec_year >= 1998, elec_year < 2017) %>%
  summarise(error_abs = mean(error_abs), error2 = sqrt(mean(error2)),
            error_abs_w = mean(error_abs_w), error2_w = sqrt(mean(error2_w)),
            error_abs_naive1 = mean(error_abs_naive1),
            error2_naive1 = sqrt(mean(error2_naive1)),
            error_abs_naive2 = mean(error_abs_naive2),
            error2_naive2 = sqrt(mean(error2_naive2)))
t_err_2$party <- 'Overall'
t_err_2 <- t_err_2 %>% select(party, error_abs:error2_naive2)

names(t_err_1) <- c('Party', rep(c('MAE', 'RMS'), 4))
names(t_err_2) <- c('Party', rep(c('MAE', 'RMS'), 4))

print(xtable(t_err_1, digits = 1), floating = F, include.rownames = F,
      include.colnames = F,
      booktabs = T, only.contents = T, hline.after = 0,
      file = 'errors.tex')

print(xtable(t_err_2, digits = 1), floating = F, include.rownames = F,
      include.colnames = F, booktabs = T, only.contents = T, hline.after = 0,
      file = 'errors_overall.tex')

errs <- read.csv('errors_states.csv', stringsAsFactors = F) %>% tbl_df

t_errs <-
  errs %>% filter(elec_year >= 1998, elec_year < 2017) %>%
  summarise(error_abs = mean(error_abs, na.rm = T),
            error2 = sqrt(mean(error2, na.rm = T)),
            error_abs_w = mean(error_abs_w, na.rm = T),
            error2_w = sqrt(mean(error2_w, na.rm = T)),
            error_abs_naive1 = mean(error_abs_naive1, na.rm = T),
            error2_naive1 = sqrt(mean(error2_naive1, na.rm = T)),
            error_abs_naive2 = mean(error_abs_naive2, na.rm = T),
            error2_naive2 = sqrt(mean(error2_naive2, na.rm = T)))
t_errs$party <- 'Overall'
t_errs <- t_errs %>% select(party, error_abs:error2_naive2)

names(t_errs) <- c('Party', rep(c('MAE', 'RMS'), 4))

print(xtable(t_errs, digits = 1), floating = F, include.rownames = F,
      include.colnames = F, booktabs = T, only.contents = T, hline.after = 0,
      file = 'errors_overall_states.tex')