# Bundestag2017Forecast
# table of predictions
library(xtable)
library(dplyr)
library(htmltab)
library(stringr)

setwd('your/directory/here')

pred <- read.csv('predictions.csv', stringsAsFactors = F)

pred$party <- c('CDU/CSU', 'SPD', 'Die Linke', 'Bündnis 90/Die Grünen',
                'FDP', 'Sonstige')

pred <- pred %>% mutate_at(vars(contains('voteshare')), round, digits = 1) %>%
  select(-poll)

names(pred) <- c('Partei', 'Prognose', 'Prognose (Gewichtetes Model)',
                 'Prä-Schulz Umfragen')


# add in most recent national polling data for 2017 ----------------------------
# for the articlet this script was called on 2017-05-23
# the manuscript represents the averages of polls available on wahlrecht.de on
# that day
url <- 'http://www.wahlrecht.de/umfragen/index.htm'

t <- htmltab(url, which = 2)

t <- t %>% select(1:(ncol(t)-1)) %>% filter(grepl('%', Allensbach)) %>%
  mutate_at(vars(Allensbach:INSA), str_replace, pattern = ' %', replacement = '') %>%
  mutate_at(vars(Allensbach:INSA), str_replace, pattern = ',', replacement = '.') %>%
  mutate_at(vars(Allensbach:INSA), as.numeric) %>%
  mutate(poll = round(rowMeans(.[2:ncol(.)]), 1)) %>%
  select(Institut, poll) %>% rename(party = Institut)

t$poll[which(t$party == 'Sonstige')] <- t$poll[which(t$party == 'Sonstige')] +
  t$poll[which(t$party == 'AfD')]
t <- t[which(t$party != 'AfD'),]

t$party <- c('CDU/CSU', 'SPD', 'Bündnis 90/Die Grünen', 'FDP', 'Die Linke',
             'Sonstige')

# merge in current polling (2017-05-23) ----------------------------------------

pred <- left_join(pred, t, by = c('Partei' = 'party'))

names(pred)[ncol(pred)] <- 'Umfragen Mai 2017'

# Add uncertainty intervals ----------------------------------------------------

uw <- read.csv('confint_unweighted.csv')

uw <- uw[c(1, 6, 2, 4, 3, 5), ]

pred$Prognose <- paste0(pred$Prognose, ' [', uw$lwr, '; ', uw$upr, ']')

w <- read.csv('confint_weighted.csv')

w <- w[c(1, 6, 2, 4, 3, 5), ]

pred$`Prognose (Gewichtetes Model)` <-
  paste0(pred$`Prognose (Gewichtetes Model)`, ' [', w$lwr, '; ', w$upr, ']')

write.csv(pred, 't_predictions.csv', row.names = F)
